==> KleckFiles(5.80.00).zip: KleckFiles/wiki/page/jkimages.js <==
var wikiMetaData = {created:'231029', modified:'231029'}; // tag data-change-note='230808/13:23/Note here'
var wikiFileText = [	
"<h1>Show-Notes Image Gallery</h1>",
'<p class="_w_glossary">',
'Jonathan describes his show-notes images as "confirming witnesses".',
'Bible scripture, video recordings and images all work together to prove out The Truth.',
'You can also ask the Lord for confirmations. In an inverted world we are blessed to have so much evidence of The Truth.',
'At some point all the data forms a clear picture and you know that you know (((G350|G350 anakrinó)) Anakrinó).',
"</p>",
	
'<ul>',
'<li><a href="https://www.show-notes.net/thisistheend/" target="_blank">show-notes.net website</a>',
	' - The official JK image server contains around 50,000 images.',
'</li>',
'<li><a href="shownotes2.html" target="_blank">KleckFiles &gt; shownotes2.html</a>',
  ' - KleckFiles backup of Show-Notes.net Image Gallery 2.',
'</li>',
'<li><a href="shownotes1.html" target="_blank">KleckFiles &gt; shownotes1.html</a>',
  ' - The original Image Gallery 1. Jonathan merged G1 into G2.',
'</li>',
'<li><a href="download/index.html" target="_blank">To Download all the show-notes Images</a>',
  '- "Choose a download server" and go to the /shownotes/ folder.',
'</li>',
'</ul>',	
	
'<p>Sample images follow..</p>',
	
'<h2 style="margin:20px 0px;">The Inverted World</h2>',
'<p>The serpents inverted things (lie, call good evil, and evil good). Peter (the Apostle that Jesus gave the Keys to the Kingdom) says in the <a href="tools.html?aop+38:5" target="_blank">Acts of Peter</a> "you must invert the world to know the kingdom of God".</p>',
'<div class="_w_images">/2023/10/19/20231019192414-50ebde5e.png|width:850px',
'||/2023/10/22/20231022043342-97a6c1f9-me.jpg',
'||/2023/07/12/20230712151852-fb45deed.jpg|width:850px;',
'||/2023/07/19/20230719152518-0bf26575.jpg|width:900px;',
'</div>',

'<h2 style="margin:20px 0px;">Man is a Worm</h2>',
'<p>Meedici worm statue. A worm with a man reflection. A woman with feet that go down to a worm.</p>',
'<div class="_w_images">/2023/10/24/20231024135629-bffe33ea.jpg|width:1100px',
'||/2023/10/25/20231025190704-b1d43d7d-me.jpg',
'||/2023/10/27/20231027174721-eeda23e3.jpg|width:900px;',
'</div>',
	
'<h2 style="margin:20px 0px;">Feeding the Worm / the Bait / the Trap</h2>',
'<p>The host body was the bait and the trap. The serpent lied and said "You won\'t die".</p>',
'<div class="_w_images">/2023/10/28/20231028072638-14102144.jpg|width:1100px',
'||/2023/10/28/20231028072646-4205cfcd-me.jpg|width:950px',
'||/2023/07/09/20230709142127-fb8f1c94.jpg',
'</div>',
	
'<h2 style="margin:20px 0px;">The Sheep are food for the Serpent Race</h2>',
'<p class="_w_glossary">Hunted for Dinner. It is the glory of Elohim to conceal a thing ((Proverbs 25:2)) </p>',
'<div class="_w_images">/2023/10/28/20231028082434-d3931cc0.jpg|width:900px',
'||/2023/03/13/20230313071551-1fada324.jpg|width:1000px',
'</div>',

'<h2 style="margin:20px 0px;">The Anti-Christ</h2>',
'<p class="_w_glossary">Proven out in many Jonathan Kleck videos</p>',
'<div class="_w_images">/2023/08/17/20230817135439-1ddbd48c-me.png|width:400px;',
'||/2023/08/17/20230817135515-da65dfe2-me.jpg|width:400px;',
'||/2023/08/17/20230817135541-abc79d39.png|width:800px;',
'||/2023/08/17/20230817135542-9fc6cffe-me.jpg|width:800px;',
'||/2023/08/17/20230817141817-d65543c0.jpg|width:800px;',
'||/2023/08/17/20230817141837-c9627634.png|width:800px;',
'||/2023/08/17/20230817172442-22b750d5-me.jpg|width:800px;',
'</div>',

'<h2 style="margin:20px 0px;">Converting a Sheep into a Locust</h2>',
'<p class="_w_glossary">Transmutation of one energy into another. The two become one.</p>',
'<div class="_w_images">/2023/08/17/20230817135444-905f8789.jpg|width:500px;',
'||/2023/08/17/20230817135446-30cbb1cd.jpg|width:500px;',
'</div>',

'<h2 style="margin:20px 0px;">The Vatican is a Serpent</h2>',
'<p class="_w_glossary">Serpents worship serpent stuff. You will know them by their fruit.</p>',
'<div class="_w_images">/2023/08/17/20230817135548-1121016c.png|width:800px;',
'||/2023/04/27/20230427144629-3a273e4a.jpg|width:1100px;',
'||/2023/04/27/20230427144636-e42eeeb0.jpg|width:1100px;',
'||/2023/04/26/20230426193628-61a3ea46.jpg|width:900px;',
'||/2023/03/13/20230313071557-f16f3682.jpg|width:1200px',
'</div>',

'<br>',
	
'<p>&GT;<a href="index.html?cover" target="_blank">Take a Tour of the Vatican</a></p>',
'<br>',
'<p>&GT; Browse more Kleck Images via <a href="shownotes2.html" target="_blank">KleckFiles &gt; shownotes2.html</a></p>',
	
	

""
];

==> KleckFiles(5.98.00).zip: KleckFiles/wiki/page/jkimages.js <==
var wikiMetaData = {created:'231029', modified:'231029'}; // tag data-change-note='230808/13:23/Note here'
var wikiFileText = [	
"<h1>Show-Notes Image Gallery</h1>",
'<p class="_w_glossary">',
'Jonathan describes his show-notes images as "confirming witnesses".',
'Bible scripture, video testimonies and images all work together to prove out The Truth.',
'In an inverted world we are blessed to have so much evidence of The Truth.',
'At some point all the data forms a clear picture, you see past the illusion and you know that you know (((G350|G350 anakrinó)) Anakrinó).',
"But wait there's more.. It's like Jesus healing your blind eyes. Like scales falling off the eyes, the Spirit engages (no more downlink, no more double-minded) and you see the world a fresh. Born again. A new creation.",
"</p>",
	
'<ul>',
'<li><a href="https://www.show-notes.net/thisistheend/" target="_blank">show-notes.net website</a>',
	' - The official JK image server contains around 50,000 images.',
'</li>',
'<li><a href="shownotes2.html" target="_blank">KleckFiles &gt; shownotes2.html</a>',
  ' - KleckFiles backup of Show-Notes.net Image Gallery 2.',
'</li>',
'<li><a href="shownotes1.html" target="_blank">KleckFiles &gt; shownotes1.html</a>',
  ' - The original Image Gallery 1. Jonathan merged G1 into G2.',
'</li>',
'<li><a href="download/index.html" target="_blank">To Download all the show-notes Images</a>',
  '- "Choose a download server" and go to the /shownotes/ folder.',
'</li>',
'</ul>',	
	
'<p>Sample images follow..</p>',
	
'<h2 style="margin:20px 0px;">The Inverted World</h2>',
'<p>The serpents inverted things (lie, call good evil, and evil good). Peter (the Apostle that Jesus gave the Keys to the Kingdom) says in the <a href="tools.html?aop+38:5" target="_blank">Acts of Peter</a> "you must invert the world to know the kingdom of God".</p>',
'<div class="_w_images">/2023/10/19/20231019192414-50ebde5e.png|width:850px',
'||/2023/10/22/20231022043342-97a6c1f9-me.jpg',
'||/2023/07/12/20230712151852-fb45deed.jpg|width:850px;',
'||/2023/07/19/20230719152518-0bf26575.jpg|width:900px;',
'</div>',

'<h2 style="margin:20px 0px;">Man is a Worm</h2>',
'<p>Meedici worm statue. A worm with a man reflection. A woman with feet that go down to a worm.</p>',
'<div class="_w_images">/2023/10/24/20231024135629-bffe33ea.jpg|width:1100px',
'||/2023/10/25/20231025190704-b1d43d7d-me.jpg',
'||/2023/10/27/20231027174721-eeda23e3.jpg|width:900px;',
'</div>',
	
'<h2 style="margin:20px 0px;">Feeding the Worm / the Bait / the Trap</h2>',
'<p>The host body was the bait and the trap. The serpent lied and said "You won\'t die".</p>',
'<div class="_w_images">/2023/10/28/20231028072638-14102144.jpg|width:1100px',
'||/2023/10/28/20231028072646-4205cfcd-me.jpg|width:950px',
'||/2023/07/09/20230709142127-fb8f1c94.jpg',
'</div>',
	
'<h2 style="margin:20px 0px;">The Sheep are food for the Serpent Race</h2>',
'<p class="_w_glossary">Hunted for Dinner. It is the glory of Elohim to conceal a thing ((Proverbs 25:2)) </p>',
'<div class="_w_images">/2023/10/28/20231028082434-d3931cc0.jpg|width:900px',
'||/2023/03/13/20230313071551-1fada324.jpg|width:1000px',
'</div>',

'<h2 style="margin:20px 0px;">The Anti-Christ</h2>',
'<p class="_w_glossary">Proven out in many Jonathan Kleck videos</p>',
'<div class="_w_images">/2023/08/17/20230817135439-1ddbd48c-me.png|width:400px;',
'||/2023/08/17/20230817135515-da65dfe2-me.jpg|width:400px;',
'||/2023/08/17/20230817135541-abc79d39.png|width:800px;',
'||/2023/08/17/20230817135542-9fc6cffe-me.jpg|width:800px;',
'||/2023/08/17/20230817141817-d65543c0.jpg|width:800px;',
'||/2023/08/17/20230817141837-c9627634.png|width:800px;',
'||/2023/08/17/20230817172442-22b750d5-me.jpg|width:800px;',
'</div>',

'<h2 style="margin:20px 0px;">Converting a Sheep into a Locust</h2>',
'<p class="_w_glossary">Transmutation of one energy into another. The two become one.</p>',
'<div class="_w_images">/2023/08/17/20230817135444-905f8789.jpg|width:500px;',
'||/2023/08/17/20230817135446-30cbb1cd.jpg|width:500px;',
'</div>',

'<h2 style="margin:20px 0px;">The Vatican is a Serpent</h2>',
'<p class="_w_glossary">Serpents worship serpent stuff. You will know them by their fruit.</p>',
'<div class="_w_images">/2023/08/17/20230817135548-1121016c.png|width:800px;',
'||/2023/04/27/20230427144629-3a273e4a.jpg|width:1100px;',
'||/2023/04/27/20230427144636-e42eeeb0.jpg|width:1100px;',
'||/2023/04/26/20230426193628-61a3ea46.jpg|width:900px;',
'||/2023/03/13/20230313071557-f16f3682.jpg|width:1200px',
'</div>',

'<br>',
	
'<p>&GT;<a href="index.html?cover" target="_blank">Take a Tour of the Vatican</a></p>',
'<br>',
'<p>&GT; Browse more Kleck Images via <a href="shownotes2.html" target="_blank">KleckFiles &gt; shownotes2.html</a></p>',
	
	

""
];
